# -*- coding: utf-8 -*-
"""
@author: mathiash
"""

import numpy as np

def calculate_air_fuel_mass_ratio(gas,fuel,oxidant,T,p,phi=1):
    """
    This funciton calculates the stoichiometric air-Fuel mass ratio from the gas object input.
    
    Input variables explained
    gas - cantera gas object. cantera.Solution('ReactionMech')
    fuel   - cantera fraction string that contains fraction of each specie in the fuel
    oxidant - cantera fraction string that contains fraction of each specie in the oxidant
    T - initial temperature condition [K] 
    p - initial pressure condition [Pa]
    phi - The equivalence ratio [-]. As default this is 1.
    """
    oxidantSpecies, oxidantFraction = find_name_and_fraction_of_species_from_cantera_input_string(oxidant)
    oxidantMassFraction=0
    gas.set_equivalence_ratio(phi,fuel,oxidant)
    gas.TP = T,p
    for specie in oxidantSpecies:
        idx = gas.species_index(specie)
        oxidantMassFraction+=gas.Y[idx]
    fuelMassFraction = 1-oxidantMassFraction
    airFuelMassRatio = (oxidantMassFraction)/(1-oxidantMassFraction)
    return airFuelMassRatio,fuelMassFraction

def get_the_filename_and_path_of_the_reaction_mechanisms(n):
    """
    select the reaction mechansim to use from a premade list of the filenames of these mechanisms
    0 - DEC_mech.cti
    1 - glaude_et_al_mech.cti
    2 - gri30.xml
    3 - sandiego_mech.cti
    4 - Peters_C3H8.cti
    5 - Sun_DMC.cti
    6 - Alexandrino_DMC.cti
    """
    model=list(['DEC_mech.cti','DMC_mech.cti','gri30.xml','sandiego_mech.cti', 
             'Peters_C3H8.cti','Sun_DMC.cti','Alexandrino_DMC.cti'])
    path='C:\\Users\\mathiash\\Documents\\PhD Study\\Python\\Cantera reaction mech'
    return model[n], path

def find_index_closest_to_value(array,value):
    for idx, values in enumerate(array):
        if idx == 0:
            diff = np.abs(values-value)
            index = idx
        if np.abs(values-value) < diff:
            diff = np.abs(values-value)
            index = idx
    return index

def find_name_and_fraction_of_species_from_cantera_input_string(string):
    """
    splits the cantera mole fraction input string and generates a list
    containing all species and a list containing the mole fractions
    """
    splitNamesList = string.split(',')
    listOfSpecies = list()
    listOfFractions = list()
    for name in splitNamesList:
        tempList = name.split(':')
        listOfSpecies.append(tempList[0])
        listOfFractions.append(float(tempList[1]))
    return listOfSpecies,listOfFractions

def get_mole_weight_for_gas_mixture(gas, species, T, p):
    gas.X = species
    gas.TP = T, p
    return gas.mean_molecular_weight

def get_fuel_mass_fraction_for_a_range_of_equivalence_ratios(gas,fuel,oxidant,T,p,phiList=0):
    """
    generates as list of fuel fraction from a list containg of equivalence ratios
    
    Input variables explained
    gas - cantera gas object. cantera.Solution('ReactionMech')
    fuel   - cantera fraction string that contains fraction of each specie in the fuel
    oxidant - cantera fraction string that contains fraction of each specie in the oxidant
    T - initial temperature condition [K] 
    p - initial pressure condition [Pa]
    phi - The equivalence ratio [-]. As default this is 0.
    """
    "variable declaration"
    outputList=list()
    if phiList == 0:
        phiList = np.arange(0.5,1.55,0.05)
    for phi in phiList:
        gas.set_equivalence_ratio(phi,fuel,oxidant)
        gas.TP = T, p
        airFuelMassRatio, fuelMassFraction = calculate_air_fuel_mass_ratio(gas,fuel,oxidant,T,p,phi)
        outputList.append(str(phi)+':'+str(fuelMassFraction))
    return outputList

if __name__ == '__main__':
    print('good day Milord')

    
